@@ -49,6 +49,7 @@
 #include <QDBusConnection>
 #include <QIcon>
 #include <QLabel>
+#include <QMenuBar>
 #include <QSplitter>
 #include <QStatusBar>
 
@@ -91,8 +92,8 @@ TopLevel::TopLevel()
   mWorkSpace = new Workspace( mSplitter );
   connect( mWorkSpace, SIGNAL(setCaption(QString)),
            SLOT(setCaption(QString)) );
-  connect( mWorkSpace, SIGNAL(currentChanged(int)),
-           SLOT(currentTabChanged(int)) );
+  connect( mWorkSpace, &QTabWidget::currentChanged,
+           this, &TopLevel::currentTabChanged );
 
   /* Create the status bar. It displays some information about the
    * number of processes and the memory consumption of the local
@@ -143,10 +144,26 @@ TopLevel::TopLevel()
   mConfigureSheetAction = actionCollection()->addAction( QStringLiteral("configure_sheet") );
   mConfigureSheetAction->setIcon( QIcon::fromTheme(QStringLiteral("configure")) );
   connect(mConfigureSheetAction, &QAction::triggered, this, &TopLevel::configureCurrentSheet);
+  // set up 'Settings' menu
+  mShowMenuBarAction = KStandardAction::showMenubar(this, &TopLevel::toggleShowMenuBar, actionCollection());
 
   retranslateUi();
 }
 
+void TopLevel::toggleShowMenuBar()
+{
+  if (mShowMenuBarAction->isChecked()) {
+    menuBar()->show();
+  } else {
+    const QString accel = mShowMenuBarAction->shortcut().toString();
+    KMessageBox::information(this, i18n("This will hide the menu bar completely."
+                                        " You can show it again by typing %1.", accel),
+                             i18n("Hide menu bar"),
+                             QStringLiteral("HideMenuBarWarning"));
+    menuBar()->hide();
+  }
+}
+
 void TopLevel::setLocalProcessController(ProcessController * localProcessController)
 {
   Q_ASSERT(!mLocalProcessController);
